Module resolved

Module resolved 

Parallel types where ReferenceOr<T> is replaced by item T.

Structs

ExamplePairing
The Example Pairing object consists of a set of example params and result. The result is what you can expect from the JSON-RPC service given the exact params.
Method
Describes the interface for the given method name. The method name is used as the method field of the JSON-RPC body. It therefore MUST be unique.
OpenRPC
This is the root object of the OpenRPC document. The contents of this object represent a whole OpenRPC document. How this object is constructed or stored is outside the scope of the OpenRPC Specification.