Server

Struct Server 

pub struct Server {
    pub name: String,
    pub url: String,
    pub summary: Option<String>,
    pub description: Option<String>,
    pub variables: Option<BTreeMap<String, ServerVariable>>,
    pub extensions: SpecificationExtensions,
}
An object representing a Server.

Fields

name: String

REQUIRED. A name to be used as the cannonical name for the server.

url: String

REQUIRED. A URL to the target host. This URL supports Server Variables and MAY be relative, to indicate that the host location is relative to the location where the OpenRPC document is being served. Server Variables are passed into the Runtime Expression to produce a server URL.

summary: Option<String>

A short summary of what the server is.

description: Option<String>

An optional string describing the host designated by the URL. GitHub Flavored Markdown syntax MAY be used for rich text representation.

variables: Option<BTreeMap<String, ServerVariable>>

A map between a variable name and its value. The value is passed into the Runtime Expression to produce a server URL.

extensions: SpecificationExtensions