Struct openrpc_types::ContentDescriptor
source · pub struct ContentDescriptor {
pub name: String,
pub summary: Option<String>,
pub description: Option<String>,
pub required: Option<bool>,
pub schema: Schema,
pub deprecated: Option<bool>,
pub extensions: SpecificationExtensions,
}Fields
name: StringREQUIRED. Name of the content that is being described. If the content described is a method parameter assignable by-name, this field SHALL define the parameter’s key (ie name).
summary: Option<String>A short summary of the content that is being described.
description: Option<String>A verbose explanation of the content descriptor behavior. GitHub Flavored Markdown syntax MAY be used for rich text representation.
required: Option<bool>Determines if the content is a required field. Default value is
false.
schema: SchemaREQUIRED. Schema that describes the content.
The Schema Object allows the definition of input and output data types. The Schema Objects MUST follow the specifications outline in the JSON Schema Specification 7 Alternatively, any time a Schema Object can be used, a Reference Object can be used in its place. This allows referencing definitions instead of defining them inline.
This object MAY be extended with Specification Extensions.
deprecated: Option<bool>Specifies that the content is deprecated and SHOULD be transitioned out of usage. Default value is
false.
extensions: SpecificationExtensionsTrait Implementations
sourceimpl Clone for ContentDescriptor
impl Clone for ContentDescriptor
sourcefn clone(&self) -> ContentDescriptor
fn clone(&self) -> ContentDescriptor
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moresourceimpl Debug for ContentDescriptor
impl Debug for ContentDescriptor
sourceimpl Default for ContentDescriptor
impl Default for ContentDescriptor
sourceimpl<'de> Deserialize<'de> for ContentDescriptor
impl<'de> Deserialize<'de> for ContentDescriptor
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
sourceimpl PartialEq for ContentDescriptor
impl PartialEq for ContentDescriptor
sourcefn eq(&self, other: &ContentDescriptor) -> bool
fn eq(&self, other: &ContentDescriptor) -> bool
self and other values to be equal, and is used
by ==.